@@ -286,26 +286,36 @@ async def rabbit_c2_rpc_callback(
             )
 
 
-async def connect_and_consume_rpc(main_config: dict):
+async def connect_and_consume_rpc(main_config: dict, debug):
     connection = None
     global hostname
     while True:
         try:
+            if debug:
+                print_flush("Connecting to rabbitmq in connect_and_consume_rpc")
             connection = await aio_pika.connect_robust(
                 host=main_config["host"],
                 login=main_config["username"],
                 password=main_config["password"],
                 virtualhost=main_config["virtual_host"]
             )
+            if debug:
+                print_flush("Successfully connected in connect_and_consume_rpc")
             channel = await connection.channel()
             # get a random queue that only the apfell server will use to listen on to catch all heartbeats
+            if debug:
+                print_flush("Declaring container specific rpc queue in connect_and_consume_rpc")
             queue = await channel.declare_queue("{}_rpc_queue".format(hostname), auto_delete=True)
-            await channel.set_qos(prefetch_count=50)
+            await channel.set_qos(prefetch_count=10)
             try:
+                if debug:
+                    print_flush("Starting to consume callbacks in connect_and_consume_rpc")
                 task = queue.consume(
                     partial(rabbit_c2_rpc_callback, channel.default_exchange)
                 )
-                result = await asyncio.wait_for(task, None)
+                result = await asyncio.gather(task)
+                if debug:
+                    print_flush("No longer consuming, starting loop again in connect_and_consume_rpc")
             except Exception as e:
                 print_flush("Exception in connect_and_consume_rpc .consume: {}".format(str(e)))
         except (ConnectionError, ConnectionRefusedError) as c:
@@ -365,7 +375,7 @@ async def mythic_service(debug: bool):
                 print("Listening for c2.modify.{}.#".format(hostname))
                 if debug:
                     print_flush("Creating task for connect_and_consume_rpc from mythic_service")
-                task4 = asyncio.ensure_future(connect_and_consume_rpc(main_config))
+                task4 = asyncio.ensure_future(connect_and_consume_rpc(main_config, debug))
                 if debug:
                     print_flush("Waiting for all tasks to finish in mythic_service")
                 result = await asyncio.gather(task, task4)
